@@ -5,9 +5,6 @@ describe 'aodh::wsgi::apache' do
   shared_examples_for 'apache serving aodh with mod_wsgi' do
     context 'with default parameters' do
       it { is_expected.to contain_class('aodh::params') }
-      it { is_expected.to contain_class('apache') }
-      it { is_expected.to contain_class('apache::mod::wsgi') }
-      it { is_expected.to contain_class('apache::mod::ssl') }
       it { is_expected.to contain_openstacklib__wsgi__apache('aodh_wsgi').with(
         :bind_port                   => 8042,
         :group                       => 'aodh',
@@ -42,13 +39,13 @@ describe 'aodh::wsgi::apache' do
           },
           :access_log_file             => '/var/log/httpd/access_log',
           :access_log_format           => 'some format',
-          :error_log_file              => '/var/log/httpd/error_log'
+          :error_log_file              => '/var/log/httpd/error_log',
+          :wsgi_script_dir             => '/var/lib/openstack/cgi-bin/aodh',
+          :wsgi_script_source          => '/my/path/app.wsgi',
+          :vhost_custom_fragment       => 'Timeout 99'
         }
       end
       it { is_expected.to contain_class('aodh::params') }
-      it { is_expected.to contain_class('apache') }
-      it { is_expected.to contain_class('apache::mod::wsgi') }
-      it { is_expected.to_not contain_class('apache::mod::ssl') }
       it { is_expected.to contain_openstacklib__wsgi__apache('aodh_wsgi').with(
         :bind_host                 => '10.42.51.1',
         :bind_port                 => 12345,
@@ -59,12 +56,13 @@ describe 'aodh::wsgi::apache' do
         :threads                   => 1,
         :user                      => 'aodh',
         :workers                   => 37,
+        :vhost_custom_fragment     => 'Timeout 99',
         :wsgi_daemon_process       => 'aodh',
         :wsgi_process_display_name => 'aodh',
         :wsgi_process_group        => 'aodh',
-        :wsgi_script_dir           => platform_params[:wsgi_script_path],
+        :wsgi_script_dir           => '/var/lib/openstack/cgi-bin/aodh',
         :wsgi_script_file          => 'app',
-        :wsgi_script_source        => platform_params[:wsgi_script_source],
+        :wsgi_script_source        => '/my/path/app.wsgi',
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
@@ -91,17 +89,13 @@ describe 'aodh::wsgi::apache' do
         case facts[:osfamily]
         when 'Debian'
           {
-            :httpd_service_name => 'apache2',
-            :httpd_ports_file   => '/etc/apache2/ports.conf',
             :wsgi_script_path   => '/usr/lib/cgi-bin/aodh',
             :wsgi_script_source => '/usr/share/aodh/app.wsgi'
           }
         when 'RedHat'
           {
-            :httpd_service_name => 'httpd',
-            :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
             :wsgi_script_path   => '/var/www/cgi-bin/aodh',
-            :wsgi_script_source => '/usr/lib/python2.7/site-packages/aodh/api/app.wsgi'
+            :wsgi_script_source => '/usr/bin/aodh-api'
           }
 
         end
